beamprofiler.beam.Beam
======================

.. currentmodule:: beamprofiler.beam

.. autoclass:: Beam
   :members:
   :undoc-members:
   :show-inheritance:
   

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Beam.__init__
   
   

   
   
   